<?php
	/*
		Plugin Name:	PDF Analytics
		Plugin URI:		https://carlhendy.com/pdf-analytics/
		Description:	Track views of PDF files hosted on your WordPress site in Google Analytics
		Version:		2.2
		Author:			Carl Hendy
		Author URI:		https://carlhendy.com/
		Text Domain:	pdf-analytics
	*/
	defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

	function pdfanalytics_htaccess()
	{
		$htaccess = ABSPATH.'.htaccess';
		if ( file_exists($htaccess) )
		{
			$current = file_get_contents($htaccess);
			if ( strpos($current, 'pdf-analytics') )
			{
				return "PDF Analytics tracking already exists in the .htaccess file";
			}
		}
		else
		{
			$current = '';
		}
		$fp = fopen($htaccess, 'w');
		fwrite($fp, "# BEGIN PDF Analytics\n");
		fwrite($fp, "<IfModule mod_rewrite.c>\nRewriteEngine On\nRewriteBase /\nRewriteRule ^(.+)\.pdf$ /wp-content/plugins/pdf-analytics/tracking.php?file=$1.pdf [L,NC,QSA]\n</IfModule>\n");
		fwrite($fp, "# END PDF Analytics\n\n");
		fwrite($fp, $current);
		fclose($fp);
		return "PDF Analytics code added to .htaccess file";
	}
	
	function pdfanalytics_detect_webserver()
	{
		$software = $_SERVER["SERVER_SOFTWARE"];
		if ( stripos($software, 'apache') !== false ) { return 'Apache'; }
		elseif ( stripos($software, 'nginx') !== false ) { return 'NGINX'; }
		else { return 'Other'; }
	}
	
	function pdfanalytics_activate_notice()
	{
		if ( get_transient( 'pdfanalytics-admin-notice-activation' ) )
		{
			echo '<div class="notice notice-success is-dismissible"><p>PDF Analytics was successfully installed, but still needs configuring. Please <a href="/wp-admin/options-general.php?page=pdfa">update your settings</a> now.</p></div>';
			
			if ( pdfanalytics_detect_webserver() !== 'NGINX' )
			{
				$update_htaccess = pdfanalytics_htaccess();
				echo '<div class="notice notice-success is-dismissible"><p>'.$update_htaccess.'</p></div>';
			}
			else
			{
				echo '<div class="notice notice-warning is-dismissible"><p>Your website uses NGINX instead of Apache for its web server, so we cannot update or use your .htaccess file. Instead, please include the following line in your NGINX configuration file (or ask your web hosting provider to do it):</p><p><code>rewrite ^(.+).pdf$ /wp-content/plugins/pdf-analytics/tracking.php?file=$1.pdf last;</code></p><p>This should go within the <em>server</em> block for this site, above the first <em>location</em> line.</p></div>';
			}
			delete_transient( 'pdfanalytics-admin-notice-activation' );
		}		
	}
	add_action( 'admin_notices', 'pdfanalytics_activate_notice' );
	
	function pdfanalytics_activate()
	{
		set_transient( 'pdfanalytics-admin-notice-activation', true, 5 );
	}
	register_activation_hook( __FILE__, 'pdfanalytics_activate' );

	function pdfanalytics_deactivate()
	{
		$htaccess = ABSPATH.'.htaccess';
		$current = file_get_contents($htaccess);
		$new = preg_replace('/\#\s*BEGIN\s*PDF Analytics(.*?)\#\s*END\s*PDF Analytics/ms', '', $current);
		$fp = fopen($htaccess, 'w');
		fwrite($fp, $new);
		fclose($fp);
	}
	register_deactivation_hook( __FILE__, 'pdfanalytics_deactivate' );

	function pdfa_register_settings() {
		add_option( 'pdfa_option_name', 'PDF Analytics');
		register_setting( 'pdfa_options_group', 'pdfa_option_trackingid' );
		register_setting( 'pdfa_options_group', 'pdfa_option_scriptpath' );
		register_setting( 'pdfa_options_group', 'pdfa_option_rooturl' );
		
		if ( isset($_POST["pdfa_option_rooturl"]) )
		{
			$dir = plugin_dir_path( __FILE__ );
			$get_config = file_get_contents($dir.'config.php');
			$get_config = preg_replace('/\'PDFA_ROOT\'\s*\,\s*\'.*?\'/i', '\'PDFA_ROOT\' , \''.$_POST["pdfa_option_rooturl"].'\'' , $get_config );
			$get_config = preg_replace('/\'PDFA_TRACKING_ID\'\s*\,\s*\'.*?\'/i', '\'PDFA_TRACKING_ID\' , \''.$_POST["pdfa_option_trackingid"].'\'' , $get_config );
			$get_config = preg_replace('/\'PDFA_TRACKING_PATH\'\s*\,\s*\'.*?\'/i', '\'PDFA_TRACKING_PATH\' , \''.$_POST["pdfa_option_scriptpath"].'\'' , $get_config );
			
			$fp = fopen($dir.'config.php', 'w');
			fwrite($fp, $get_config);
			fclose($fp);
		}
	}
	add_action( 'admin_init', 'pdfa_register_settings' );

	function pdfa_register_options_page() {
		add_options_page('PDF Analytics', 'PDF Analytics', 'manage_options', 'pdfa', 'pdfa_options_page');
	}
	add_action('admin_menu', 'pdfa_register_options_page');

	function pdfa_options_page()
	{
	?>
		<div class="wrap">
			<h1>PDF Analytics</h1>
			<div style="padding: 20px; margin: 20px; background-color: #fff; border: 1px solid #ccc;">
				<p><?php echo '<img src="' . plugins_url( 'pdf-icon.svg', __FILE__ ) . '" width="96" height="96" align="left">'; ?>
					This plugin enables you to track visits to your website's PDF documents, in Google Analytics. PDF files cannot run Google's tracking code, so are normally blind spots where visitors disappear. PDF Analytics changes this, by sending PDF requests through this plugin first and using Google's official API to record the view. As well as recording the visit, PDF Analytics can re-use existing GA Sessions (to follow the visitor's click journey), record "UTM" tagging data from marketing campaigns and extract SEO/PPC keyword data from search engine traffic (if provided). For more information, <a href="https://carlhendy.com/pdf-analytics/">check out my website</a>.</p>
			</div>
			<div style="padding: 20px; margin: 20px; background-color: #fff; border: 1px solid #ccc;">
				<form method="post" action="options.php">
					<?php settings_fields( 'pdfa_options_group' ); ?>
					<?php do_settings_sections( 'pdfa_options_group' ); ?>
					<h3>The settings below are needed before PDF Analytics will work</h3>
					<p>Your Google Analytics Tracking ID can be found by <a href="https://analytics.google.com/analytics/">visiting GA</a>, going to "Admin", selecting the correct "Account" and "Property" for this website and selecting "Tracking Info" > "Tracking Code". The "Tracking ID" will be in the format "UA-000000000" or "UA-000000000-0". If Google Analytics is already installed on this website, you can also find the Tracking ID in your HTML source code, by searching for "UA-".</p>
					<table>
						<?php
							$guess_root = trim( get_home_url() , "/ \t\n\r\0\x0B" );
							$rooturl = ( get_option('pdfa_option_rooturl') == FALSE ) ? $guess_root : get_option('pdfa_option_rooturl');
							$guess_path = trim( WP_PLUGIN_DIR ) .'/pdf-analytics/tracking.php';
							$scriptpath = ( get_option('pdfa_option_scriptpath') == FALSE ) ? $guess_path : get_option('pdfa_option_scriptpath');
						?>
						<tr valign="middle">
							<th scope="row" align="right"><label for="pdfa_option_trackingid">Google Analytics Tracking ID</label></th>
							<td><input type="text" id="pdfa_option_trackingid" name="pdfa_option_trackingid" value="<?php echo get_option('pdfa_option_trackingid'); ?>" placeholder="UA-000000000-0" style="width: 300px;" /> (You'll need to look this up)</td>
						</tr>
						<tr valign="middle">
							<th scope="row" align="right"><label for="pdfa_option_rooturl">Website Root URL</label></th>
							<td><input type="text" id="pdfa_option_rooturl" name="pdfa_option_rooturl" value="<?php echo $rooturl; ?>" placeholder="https://www.yourwebsite.com" style="width: 300px;" /> (No trailing "/" slash, we'll attempt to fill this for you)</td>
						</tr>
						<tr valign="middle">
							<th scope="row" align="right"><label for="pdfa_option_scriptpath">Tracking Script Path</label></th>
							<td><input type="text" id="pdfa_option_scriptpath" name="pdfa_option_scriptpath" value="<?php echo $scriptpath; ?>" placeholder="/home/site/public/wp-content/plugins/pdf-analytics/tracking.php" style="width: 300px;" /> (We'll attempt to fill this for you)</td>
						</tr>
					</table>
					<?php  submit_button(); ?>
				</form>
			</div>
		</div>
		<div style="position: fixed; bottom: 50px;">
			<p><small>PDF Icon from <a href="https://fontawesome.com/license">FontAwesome</a>, licensed under the Creative Commons Attribution 4.0 International license</small></p>
		</div>
	<?php
	}


?>